s/non-zero/nonzero/g
authorJim Meyering <jim@meyering.net>
Mon, 27 Nov 1995 05:34:31 +0000 (05:34 +0000)
committerJim Meyering <jim@meyering.net>
Mon, 27 Nov 1995 05:34:31 +0000 (05:34 +0000)
33 files changed:
src/chgrp.c
src/chmod.c
src/chown.c
src/cp.c
src/date.c
src/dd.c
src/df.c
src/du.c
src/env.c
src/id.c
src/install.c
src/ln.c
src/logname.c
src/ls.c
src/mkdir.c
src/mkfifo.c
src/mknod.c
src/mv.c
src/pathchk.c
src/printenv.c
src/rm.c
src/rmdir.c
src/seq.c
src/sleep.c
src/stty.c
src/su.c
src/tee.c
src/test.c
src/touch.c
src/tty.c
src/uname.c
src/who.c
src/whoami.c

index 0cc33c6..8de7f39 100644 (file)
@@ -73,10 +73,10 @@ static int changes_only;
 /* The name of the group to which ownership of the files is being given. */
 static char *groupname;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
index eb7116b..cae5d7e 100644 (file)
@@ -57,10 +57,10 @@ static int verbose;
 /* If nonzero, describe only modes that change. */
 static int changes_only;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
@@ -94,7 +94,7 @@ describe_change (char *file, short unsigned int mode, int changed)
 }
 
 /* Change the mode of FILE according to the list of operations CHANGES.
-   If DEREF_SYMLINK is non-zero and FILE is a symbolic link, change the
+   If DEREF_SYMLINK is nonzero and FILE is a symbolic link, change the
    mode of the referenced file.  If DEREF_SYMLINK is zero, ignore symbolic
    links.  Return 0 if successful, 1 if errors occurred. */
 
index bb2ad6e..f3bbf45 100644 (file)
@@ -79,10 +79,10 @@ static char *username;
 /* The name of the group to which ownership of the files is being given. */
 static char *groupname;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
index 145fb02..4607d9a 100644 (file)
--- a/src/dd.c
+++ b/src/dd.c
@@ -305,10 +305,10 @@ static unsigned char const ebcdic_to_ascii[] =
   070, 071, 0372, 0373, 0374, 0375, 0376, 0377
 };
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
index 222f973..a8400ec 100644 (file)
--- a/src/env.c
+++ b/src/env.c
@@ -96,10 +96,10 @@ extern char **environ;
 /* The name by which this program was run. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
@@ -150,7 +150,7 @@ main (argc, argv, envp)
 
   if (optind != argc && !strcmp (argv[optind], "-"))
     ignore_environment = 1;
-  
+
   environ = dummy_environ;
   environ[0] = NULL;
 
index b02ba78..d161ac3 100644 (file)
--- a/src/ln.c
+++ b/src/ln.c
@@ -92,10 +92,10 @@ static int hard_dir_link;
    symlink-to-dir before creating the new link.  */
 static int dereference_dest_dir_symlinks = 1;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
@@ -177,7 +177,7 @@ do_link (char *source, char *dest)
       char *new_dest;
       PATH_BASENAME_CONCAT (new_dest, dest, source);
       dest = new_dest;
-      /* Set this to non-zero to force another call to lstat
+      /* Set this to nonzero to force another call to lstat
         with the new destination.  */
       lstat_status = 1;
     }
index 44b53a8..e12c3eb 100644 (file)
 /* The name this program was run with. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
index e07c0ea..8d23487 100644 (file)
--- a/src/ls.c
+++ b/src/ls.c
@@ -465,10 +465,10 @@ static int format_needs_stat;
 
 static int exit_status;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
@@ -1673,7 +1673,7 @@ extract_dirs_from_files (const char *dirname, int recursive)
   files_index = j;
 }
 \f
-/* Return non-zero if `name' doesn't end in `.' or `..'
+/* Return nonzero if `name' doesn't end in `.' or `..'
    This is so we don't try to recurse on `././././. ...' */
 
 static int
index 6312bb3..6b4aad8 100644 (file)
@@ -44,10 +44,10 @@ char *program_name;
 /* If nonzero, ensure that all parents of the specified directory exist.  */
 static int path_mode;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
index 86e3377..ec33aef 100644 (file)
 /* The name this program was run with. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
index 30989bc..580ccae 100644 (file)
 /* The name this program was run with. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
index 2cea495..089a261 100644 (file)
--- a/src/mv.c
+++ b/src/mv.c
@@ -91,10 +91,10 @@ static uid_t myeuid;
 /* FIXME */
 static struct stat dest_stats, source_stats;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
index 2b10b8c..9c137ee 100644 (file)
@@ -99,10 +99,10 @@ static void usage ();
 /* The name this program was run with. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
@@ -174,13 +174,13 @@ static char const portable_chars[256] =
   1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, /* 80-95 */
   0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, /* 96-111 */
   1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, /* 112-127 */
-  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
 };
 
index f631ab1..8cee176 100644 (file)
 /* The name this program was run with. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
index 2f9593e..26c5286 100644 (file)
--- a/src/rm.c
+++ b/src/rm.c
@@ -93,10 +93,10 @@ static int unlink_dirs;
 /* If nonzero, stdin is a tty.  */
 static int stdin_tty;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_opts[] =
index 8c2f75b..13593fb 100644 (file)
@@ -39,10 +39,10 @@ char *program_name;
 /* If nonzero, remove empty parent directories. */
 static int empty_paths;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
index ec72eea..2cd1bc3 100644 (file)
--- a/src/su.c
+++ b/src/su.c
@@ -161,10 +161,10 @@ extern char **environ;
 /* The name this program was run with.  */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 /* If nonzero, pass the `-f' option to the subshell.  */
index b81d375..2e98024 100644 (file)
--- a/src/tty.c
+++ b/src/tty.c
@@ -39,10 +39,10 @@ char *program_name;
 /* If nonzero, return an exit status but produce no output. */
 static int silent;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
index 6fd34d8..dc4bcd3 100644 (file)
@@ -20,7 +20,7 @@
    -s, --sysname       SunOS
    -n, --nodename      rocky8
    -r, --release       4.0
-   -v, --version       
+   -v, --version
    -m, --machine       sun
    -a, --all           SunOS rocky8 4.0  sun
 
@@ -63,10 +63,10 @@ static unsigned char toprint;
 /* The name this program was run with, for error messages. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
index d311342..cb0125f 100644 (file)
--- a/src/who.c
+++ b/src/who.c
@@ -92,10 +92,10 @@ char *xmalloc ();
 /* The name this program was run with. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 #ifdef WHO
@@ -226,7 +226,7 @@ print_entry (this)
       mesg = '?';
       last_change = 0;
     }
-  
+
   printf ("%-8.*s", (int) sizeof (this->ut_name), this->ut_name);
   if (include_mesg)
     printf ("  %c  ", mesg);
@@ -492,7 +492,7 @@ who_am_i (filename)
   if (tty == NULL)
     return;
   tty += 5;                    /* Remove "/dev/".  */
-  
+
   utmp_entry = search_entries (read_utmp (filename), tty);
   if (utmp_entry == NULL)
     return;
index 2a7b45e..f762dbc 100644 (file)
 /* The name this program was run with. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
--- a/src/cp.c
+++ b/src/cp.c
@@ -130,10 +130,10 @@ static int umask_kill;
 /* This process's effective user ID.  */
 static uid_t myeuid;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_opts[] =
@@ -459,7 +459,7 @@ do_copy (int argc, char **argv)
 }
 \f
 /* Copy the file SRC_PATH to the file DST_PATH.  The files may be of
-   any type.  NEW_DST should be non-zero if the file DST_PATH cannot
+   any type.  NEW_DST should be nonzero if the file DST_PATH cannot
    exist because its parent directory was just created; NEW_DST should
    be zero if DST_PATH might already exist.  DEVICE is the device
    number of the parent directory, or 0 if the parent of this file is
@@ -1037,7 +1037,7 @@ re_protect (char *const_dst_path, int src_offset, struct dir_attr *attr_list)
 }
 \f
 /* Read the contents of the directory SRC_PATH_IN, and recursively
-   copy the contents to DST_PATH_IN.  NEW_DST is non-zero if
+   copy the contents to DST_PATH_IN.  NEW_DST is nonzero if
    DST_PATH_IN is a directory that was created previously in the
    recursion.   SRC_SB and ANCESTORS describe SRC_PATH_IN.
    Return 0 if successful, -1 if an error occurs. */
@@ -1188,13 +1188,13 @@ copy_reg (char *src_path, char *dst_path)
        {
          buf[n_read] = 1;      /* Sentinel to stop loop.  */
 
/* Find first non-zero *word*, or the word with the sentinel.  */
 
          ip = (int *) buf;
          while (*ip++ == 0)
            ;
 
/* Find the first non-zero *byte*, or the sentinel.  */
 
          cp = (char *) (ip - 1);
          while (*cp++ == 0)
index 49ca9ef..378b302 100644 (file)
@@ -50,13 +50,13 @@ static void usage ();
 /* The name this program was run with, for error messages. */
 char *program_name;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
/* If non-zero, print or set Coordinated Universal Time.  */
 static int universal_time = 0;
 
 static struct option const long_options[] =
@@ -76,7 +76,7 @@ static struct option const long_options[] =
 /* Parse each line in INPUT_FILENAME as with --date and display the
    each resulting time and date.  If the file cannot be opened, tell why
    then exit.  Issue a diagnostic for any lines that cannot be parsed.
-   If any line cannot be parsed, return non-zero;  otherwise return zero.  */
+   If any line cannot be parsed, return nonzero;  otherwise return zero.  */
 
 static int
 batch_convert (input_filename, format)
@@ -130,10 +130,10 @@ static int umask_kill;
 static uid_t myeuid;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -130,10 +130,10 @@ static int umask_kill;
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
@@ -1188,13 +1188,13 @@ copy_reg (char *src_path, char *dst_path)
          buf[n_read] = 1;      /* Sentinel to stop loop.  */
 
-         /* Find first non-zero *word*, or the word with the sentinel.  */
+         /* Find first nonzero *word*, or the word with the sentinel.  */
 
          ip = (int *) buf;
@@ -1188,13 +1188,13 @@ copy_reg (char *src_path, char *dst_path)
            ;
 
-         /* Find the first non-zero *byte*, or the sentinel.  */
+         /* Find the first nonzero *byte*, or the sentinel.  */
 
          cp = (char *) (ip - 1);
@@ -50,13 +50,13 @@ static void usage ();
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -50,13 +50,13 @@ static void usage ();
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
@@ -50,13 +50,13 @@ static void usage ();
 static int show_version;
 
-/* If non-zero, print or set Coordinated Universal Time.  */
+/* If nonzero, print or set Coordinated Universal Time.  */
 static int universal_time = 0;
 
index dae19ee..09f66ab 100644 (file)
--- a/src/df.c
+++ b/src/df.c
@@ -81,7 +81,7 @@ static int posix_format;
 
 /* If nonzero, invoke the `sync' system call before getting any usage data.
    Using this option can make df very slow, especially with many or very
-   busy disks.  Default to non-zero because the sync call does make a
+   busy disks.  Default to nonzero because the sync call does make a
    difference on some systems -- SunOs4.1.3, for one.  I have been assured
    that it is *not* necessary on Linux, so there should be a way to
    configure this.  FIXME.  */
@@ -119,13 +119,13 @@ static struct fs_type_list *fs_exclude_list;
 /* Linked list of mounted filesystems. */
 static struct mount_entry *mount_list;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
/* If non-zero, print filesystem type as well.  */
 static int print_type;
 
 static struct option const long_options[] =
@@ -119,13 +119,13 @@ static struct fs_type_list *fs_exclude_list;
 static struct mount_entry *mount_list;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -119,13 +119,13 @@ static struct fs_type_list *fs_exclude_list;
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
@@ -119,13 +119,13 @@ static struct fs_type_list *fs_exclude_list;
 static int show_version;
 
-/* If non-zero, print filesystem type as well.  */
+/* If nonzero, print filesystem type as well.  */
 static int print_type;
 
index 41e8b53..0041232 100644 (file)
--- a/src/du.c
+++ b/src/du.c
@@ -159,10 +159,10 @@ static int (*xstat) ();
 /* The exit status to use if we don't get any fatal errors. */
 static int exit_status;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
 /* Grand total size of all args. */
@@ -554,7 +554,7 @@ hash_reset (void)
 
 /* Insert an item (inode INO and device DEV) in the hash
    structure in the global variable `htab', if an entry with the same data
-   was not found already.  Return zero if the item was inserted and non-zero
+   was not found already.  Return zero if the item was inserted and nonzero
    if it wasn't.  */
 
 static int
@@ -621,7 +621,7 @@ hash_insert (ino_t ino, dev_t dev)
 }
 
 /* Insert INO and DEV in the hash structure HTAB, if not
-   already present.  Return zero if inserted and non-zero if it
+   already present.  Return zero if inserted and nonzero if it
    already existed.  */
 
 static int
@@ -159,10 +159,10 @@ static int (*xstat) ();
 static int exit_status;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -159,10 +159,10 @@ static int (*xstat) ();
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
index 816b3b8..0bce0eb 100644 (file)
--- a/src/id.c
+++ b/src/id.c
@@ -84,10 +84,10 @@ static gid_t rgid, egid;
 /* The number of errors encountered so far. */
 static int problems = 0;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
@@ -285,14 +285,14 @@ print_full_info (username)
     problems++;
   else
     printf ("(%s)", pwd->pw_name);
-  
+
   printf (" gid=%u", (unsigned) rgid);
   grp = getgrgid (rgid);
   if (grp == NULL)
     problems++;
   else
     printf ("(%s)", grp->gr_name);
-  
+
   if (euid != ruid)
     {
       printf (" euid=%u", (unsigned) euid);
@@ -302,7 +302,7 @@ print_full_info (username)
       else
        printf ("(%s)", pwd->pw_name);
     }
-  
+
   if (egid != rgid)
     {
       printf (" egid=%u", (unsigned) egid);
index 86dc6f1..dea8283 100644 (file)
@@ -134,10 +134,10 @@ static int strip_files;
 /* If nonzero, install a directory instead of a regular file. */
 static int dir_arg;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
@@ -303,7 +303,7 @@ static char buffer[READ_SIZE];
 
 /* Copy file FROM onto file TO, creating TO if necessary.
    Return 0 if the copy is successful, 1 if not.  If the copy is
-   successful, set *TO_CREATED to non-zero if TO was created (if it did
+   successful, set *TO_CREATED to nonzero if TO was created (if it did
    not exist or did, but was unlinked) and to zero otherwise.  If the
    copy fails, don't modify *TO_CREATED.  */
 
@@ -394,7 +394,7 @@ copy_file (char *from, char *to, int *to_created)
 }
 
 /* Set the attributes of file or directory PATH.
-   If NO_NEED_TO_CHOWN is non-zero, don't call chown.
+   If NO_NEED_TO_CHOWN is nonzero, don't call chown.
    Return 0 if successful, 1 if not. */
 
 static int
@@ -84,10 +84,10 @@ static gid_t rgid, egid;
 static int problems = 0;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -84,10 +84,10 @@ static gid_t rgid, egid;
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
@@ -134,10 +134,10 @@ static int strip_files;
 static int dir_arg;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -134,10 +134,10 @@ static int strip_files;
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
index d80a9c0..8f144aa 100644 (file)
--- a/src/seq.c
+++ b/src/seq.c
@@ -30,7 +30,7 @@ static int check_format ();
 static char *get_width_format ();
 static int print_numbers ();
 
/* If non-zero print all number with equal width. */
 static int equal_width;
 
 /* The printf(3) format used for output. */
@@ -45,10 +45,10 @@ char *program_name;
 /* The string used to separate two number. */
 static char *separator;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
 /* The increment. */
@@ -111,7 +111,7 @@ main (argc, argv)
   from = 1.0;
   step_is_set = 0;
 
-  /* We have to handle negative numbers in the command line but this 
+  /* We have to handle negative numbers in the command line but this
      conflicts with the command line arguments.  So the getopt mode is
      REQUIRE_ORDER (the '+' in the format string) and it abort on the
      first non-option or negative number.  */
index 15b8fb0..e8f5cd9 100644 (file)
@@ -29,10 +29,10 @@ static long argdecode ();
 /* The name by which this program was run. */
 char *program_name;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
index e177a48..7ca5e1f 100644 (file)
@@ -1186,7 +1186,7 @@ set_speed (type, arg, mode)
 
 /* Get window size information.  First try getting the information
    associated with standard output and if that fails, try standard input.
-   Return zero for success, non-zero if both ioctl's failed.  */
+   Return zero for success, nonzero if both ioctl's failed.  */
 
 static int
 get_win_size (win)
@@ -30,7 +30,7 @@ static int check_format ();
 static int print_numbers ();
 
-/* If non-zero print all number with equal width. */
+/* If nonzero print all number with equal width. */
 static int equal_width;
 
@@ -45,10 +45,10 @@ char *program_name;
 static char *separator;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -45,10 +45,10 @@ char *program_name;
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
@@ -29,10 +29,10 @@ static long argdecode ();
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -29,10 +29,10 @@ static long argdecode ();
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
index ea4f1bf..1464d3b 100644 (file)
--- a/src/tee.c
+++ b/src/tee.c
@@ -41,10 +41,10 @@ static int ignore_interrupts;
 /* The name that this program was run with. */
 char *program_name;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
@@ -85,7 +85,7 @@ main (argc, argv)
 {
   int errs;
   int optc;
-       
+
   program_name = argv[0];
   append = 0;
   ignore_interrupts = 0;
index 6675c3e..4baab19 100644 (file)
@@ -248,7 +248,7 @@ integer_expected_error (pch)
   test_syntax_error (_("integer expression expected %s\n"), pch);
 }
 
/* Return non-zero if the characters pointed to by STRING constitute a
    valid number.  Stuff the converted number into RESULT if RESULT is
    a non-null pointer to a long. */
 static int
@@ -309,7 +309,7 @@ isint (string, result)
 }
 
 /* Find the modification time of FILE, and stuff it into AGE, a pointer
-   to a long.  Return non-zero if successful, else zero. */
+   to a long.  Return nonzero if successful, else zero. */
 static int
 age_of (filename, age)
      char *filename;
@@ -882,7 +882,7 @@ binop (s)
          (STREQ (s, "-gt")) || (STREQ (s, "-ge")));
 }
 
/* Return non-zero if OP is one of the test command's unary operators. */
 static int
 unop (op)
      int op;
@@ -1008,7 +1008,7 @@ EXPRESSION is true or false and sets exit status.  It is one of:\n\
   EXPRESSION1 -a EXPRESSION2   both EXPRESSION1 and EXPRESSION2 are true\n\
   EXPRESSION1 -o EXPRESSION2   either EXPRESSION1 or EXPRESSION2 is true\n\
 \n\
-  [-n] STRING          the length of STRING is non-zero\n\
+  [-n] STRING          the length of STRING is nonzero\n\
   -z STRING            the length of STRING is zero\n\
   STRING1 = STRING2    the strings are equal\n\
   STRING1 != STRING2   the strings are not equal\n\
index b539353..c49ddb2 100644 (file)
@@ -93,10 +93,10 @@ static char *ref_file;
 /* Info about the reference file. */
 static struct stat ref_stats;
 
/* If non-zero, display usage information and exit.  */
 static int show_help;
 
/* If non-zero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const longopts[] =
@@ -41,10 +41,10 @@ static int ignore_interrupts;
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -41,10 +41,10 @@ static int ignore_interrupts;
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
@@ -248,7 +248,7 @@ integer_expected_error (pch)
 }
 
-/* Return non-zero if the characters pointed to by STRING constitute a
+/* Return nonzero if the characters pointed to by STRING constitute a
    valid number.  Stuff the converted number into RESULT if RESULT is
    a non-null pointer to a long. */
@@ -882,7 +882,7 @@ binop (s)
 }
 
-/* Return non-zero if OP is one of the test command's unary operators. */
+/* Return nonzero if OP is one of the test command's unary operators. */
 static int
 unop (op)
@@ -93,10 +93,10 @@ static char *ref_file;
 static struct stat ref_stats;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
@@ -93,10 +93,10 @@ static char *ref_file;
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
index 6a9baf1..29d279d 100644 (file)